@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef EVENT_H
-#define EVENT_H
+#pragma once
 
 #include "kactivitymanagerd_plugin_export.h"
 
@@ -63,5 +62,3 @@ typedef QList<Event> EventList;
 
 Q_DECLARE_METATYPE(Event)
 Q_DECLARE_METATYPE(EventList)
-
-#endif // EVENT_H
